@@ -1,11 +1,11 @@
 # -*- coding:utf-8 -*-
-
 '''
-sending email via Python.
+发送 E-mail 的脚本
 '''
 
 import smtplib
 from email.mime.text import MIMEText
+
 from config import SMTP_CFG
 
 
@@ -27,5 +27,6 @@ def send_mail(to_list, sub, content, cc=None):
         smtper.sendmail(sender, to_list, msg.as_string())
         smtper.close()
         return True
-    except:
+    except Exception as err:
+        print(repr(err))
         return False
