@@ -1,4 +1,4 @@
-from config import CMS_CFG, router_post
+from config import CMS_CFG, post_cfg
 from torcms.core.base_handler import BaseHandler
 from torcms.model.classify_model import MClassify
 
@@ -53,11 +53,13 @@ class ClassifyHandler(BaseHandler):
             postnum = MClassify.count_of_classify(i.uid)
             arr_num.append(postnum)
 
-        self.render('static_pages/classify/index.html',
-                    postinfo=postinfo,
-                    postcount=MClassify.count_of_certain(),
-                    userinfo=self.userinfo,
-                    cfg=CMS_CFG,
-                    kwd=kwd,
-                    arr_num=arr_num,
-                    router_post=router_post)
+        self.render(
+            'static_pages/classify/index.html',
+            postinfo=postinfo,
+            postcount=MClassify.count_of_certain(),
+            userinfo=self.userinfo,
+            cfg=CMS_CFG,
+            kwd=kwd,
+            arr_num=arr_num,
+            router_post=post_cfg,
+        )
