@@ -5,6 +5,7 @@ The basic HTML Page handler.
 
 import json
 import random
+import time
 
 from concurrent.futures import ThreadPoolExecutor
 
@@ -13,7 +14,7 @@ import tornado.gen
 import tornado.ioloop
 import tornado.web
 
-from config import router_post
+from config import post_cfg
 from torcms.core import privilege, tools
 from torcms.core.base_handler import BaseHandler
 from torcms.core.tool.sqlite_helper import MAcces
@@ -118,7 +119,7 @@ def update_label(post_id, post_data):
     elif ';' in post_data['tags']:
         tags_arr = [x.strip() for x in post_data['tags'].split(';')]
     else:
-        tags_arr = [x.strip() for x in post_data['tags'].split(' ')]
+        tags_arr = [x.strip() for x in post_data['tags'].split(',')]
 
     for tag_name in tags_arr:
         if tag_name == '':
@@ -137,6 +138,7 @@ class PostHandler(BaseHandler):
     '''
     The basic HTML Page handler.
     '''
+
     executor = ThreadPoolExecutor(2)
 
     def initialize(self, **kwargs):
@@ -200,11 +202,17 @@ class PostHandler(BaseHandler):
         '''
         The default page of POST.
         '''
-        self.render('post_{0}/post_index.html'.format(self.kind),
-                    userinfo=self.userinfo,
-                    kwd={
-                        'uid': '',
-                    })
+        if self.filter_view:
+            tmpl = f'tmpl_{self.kind}/tpl_index.html'
+        else:
+            tmpl = f'post_{self.kind}/post_index.html'
+        self.render(
+            tmpl,
+            userinfo=self.userinfo,
+            kwd={
+                'uid': '',
+            },
+        )
 
     def _gen_uid(self):
         '''
@@ -226,8 +234,11 @@ class PostHandler(BaseHandler):
 
         cat_id = self.__get_cat_id(rec)
 
-        logger.info('For templates: catid: {0},  filter_view: {1}'.format(
-            cat_id, self.filter_view))
+        logger.info(
+            'For templates: catid: {0},  filter_view: {1}'.format(
+                cat_id, self.filter_view
+            )
+        )
 
         if cat_id and self.filter_view:
             tmpl = 'autogen/view/view_{0}.html'.format(cat_id)
@@ -246,7 +257,7 @@ class PostHandler(BaseHandler):
         return cat_id
 
     @tornado.web.authenticated
-    @privilege.auth_add
+    @privilege.permission(action='can_add')
     def _to_add_with_category(self, catid):
         '''
         Used for info2.
@@ -260,11 +271,12 @@ class PostHandler(BaseHandler):
             'gcat0': catid,
             'parentname': MCategory.get_by_uid(catinfo.pid).name,
             'catname': MCategory.get_by_uid(catid).name,
+            'router': post_cfg[self.kind]['router'],
         }
 
-        self.render('autogen/add/add_{0}.html'.format(catid),
-                    userinfo=self.userinfo,
-                    kwd=kwd)
+        self.render(
+            'autogen/add/add_{0}.html'.format(catid), userinfo=self.userinfo, kwd=kwd
+        )
 
     def _view_or_add(self, uid):
         '''
@@ -276,19 +288,16 @@ class PostHandler(BaseHandler):
                 self.viewinfo(postinfo)
             else:
                 self.redirect(
-                    '/{0}/{1}'.format(
-                        router_post[postinfo.kind],
-                        postinfo.uid
-                    ),
-                    permanent=True)
+                    '/{0}/{1}'.format(post_cfg[postinfo.kind]['router'], postinfo.uid),
+                    permanent=True,
+                )
 
         elif self.userinfo:
             self._to_add(uid=uid)
         else:
             self.show404()
 
-    @tornado.web.authenticated
-    @privilege.auth_add
+    @privilege.permission(action='can_add')
     def _to_add(self, **kwargs):
         '''
         Used for info1.
@@ -305,16 +314,16 @@ class PostHandler(BaseHandler):
                 uid = kwargs['uid']
             else:
                 uid = ''
-            self.render('post_{0}/post_add.html'.format(self.kind),
-                        tag_infos=MCategory.query_all(by_order=True,
-                                                      kind=self.kind),
-                        userinfo=self.userinfo,
-                        kwd={
-                            'uid': uid,
-                        })
+            self.render(
+                'post_{0}/post_add.html'.format(self.kind),
+                tag_infos=MCategory.query_all(by_order=True, kind=self.kind),
+                userinfo=self.userinfo,
+                kwd={
+                    'uid': uid,
+                },
+            )
 
-    @tornado.web.authenticated
-    @privilege.auth_edit
+    @privilege.permission(action='can_edit')
     def _to_edit(self, infoid):
         '''
         render the HTML page for post editing.
@@ -350,9 +359,8 @@ class PostHandler(BaseHandler):
             'catname': '',
             'parentlist': MCategory.get_parent_list(),
             'userip': self.request.remote_ip,
-            'extinfo': json.dumps(postinfo.extinfo,
-                                  indent=2,
-                                  ensure_ascii=False),
+            'extinfo': json.dumps(postinfo.extinfo, indent=2, ensure_ascii=False),
+            'router': post_cfg[postinfo.kind]['router'],
         }
 
         if self.filter_view:
@@ -362,20 +370,21 @@ class PostHandler(BaseHandler):
 
         logger.info('Meta template: {0}'.format(tmpl))
 
-        self.render(tmpl,
-                    kwd=kwd,
-                    postinfo=postinfo,
-                    catinfo=catinfo,
-                    pcatinfo=p_catinfo,
-                    userinfo=self.userinfo,
-                    cat_enum=MCategory.get_qian2(catid[:2]),
-                    tag_infos=MCategory.query_all(by_order=True,
-                                                  kind=self.kind),
-                    tag_infos2=MCategory.query_all(by_order=True,
-                                                   kind=self.kind),
-                    app2tag_info=MPost2Catalog.query_by_entity_uid(
-                        infoid, kind=self.kind).objects(),
-                    app2label_info=MPost2Label.get_by_uid(infoid).objects())
+        self.render(
+            tmpl,
+            kwd=kwd,
+            postinfo=postinfo,
+            catinfo=catinfo,
+            pcatinfo=p_catinfo,
+            userinfo=self.userinfo,
+            cat_enum=MCategory.get_qian2(catid[:2]),
+            tag_infos=MCategory.query_all(by_order=True, kind=self.kind),
+            tag_infos2=MCategory.query_all(by_order=True, kind=self.kind),
+            app2tag_info=MPost2Catalog.query_by_entity_uid(
+                infoid, kind=self.kind
+            ).objects(),
+            app2label_info=MPost2Label.get_by_uid(infoid).objects(),
+        )
 
     def _gen_last_current_relation(self, post_id):
         '''
@@ -416,16 +425,16 @@ class PostHandler(BaseHandler):
         MAcces.add(postinfo.uid)
 
         if self.get_current_user() and self.userinfo:
-            MUsage.add_or_update(self.userinfo.uid, postinfo.uid,
-                                 postinfo.kind)
+            MUsage.add_or_update(self.userinfo.uid, postinfo.uid, postinfo.kind)
 
         self.set_cookie('user_pass', kwd['cookie_str'])
 
         tmpl = self.ext_tmpl_view(postinfo)
 
         if self.userinfo:
-            recent_apps = MUsage.query_recent(self.userinfo.uid, postinfo.kind,
-                                              6).objects()[1:]
+            recent_apps = MUsage.query_recent(
+                self.userinfo.uid, postinfo.kind, 6
+            ).objects()[1:]
         else:
             recent_apps = []
         logger.info('The Info Template: {0}'.format(tmpl))
@@ -441,10 +450,15 @@ class PostHandler(BaseHandler):
             rand_recs=rand_recs,
             subcats=MCategory.query_sub_cat(p_catinfo.uid) if p_catinfo else '',
             ad_switch=random.randint(1, 18),
-            tag_info=filter(lambda x: not x.tag_name.startswith('_'),
-                            MPost2Label.get_by_uid(postinfo.uid).objects()),
+            tag_info=filter(
+                lambda x: not x.tag_name.startswith('_'),
+                MPost2Label.get_by_uid(postinfo.uid).objects(),
+            ),
             recent_apps=recent_apps,
-            cat_enum=cat_enum1)
+            cat_enum=cat_enum1,
+            router=post_cfg[catinfo.kind]['router'],
+            post_type=post_cfg[catinfo.kind].get('show', post_cfg[catinfo.kind].get('router')),
+        )
 
     def _the_view_kwd(self, postinfo):
         '''
@@ -466,7 +480,7 @@ class PostHandler(BaseHandler):
             'parentlist': MCategory.get_parent_list(),
             'parentname': '',
             'catname': '',
-            'router': router_post[postinfo.kind]
+            'router': post_cfg[postinfo.kind]['router'],
         }
         return kwd
 
@@ -480,16 +494,15 @@ class PostHandler(BaseHandler):
             cat_uid = cat_rec.tag_id
             cat_uid_arr.append(cat_uid)
         logger.info('info category: {0}'.format(cat_uid_arr))
-        rel_recs = MRelation.get_app_relations(uid, 8,
-                                               kind=self.kind).objects()
+        rel_recs = MRelation.get_app_relations(uid, 8, kind=self.kind).objects()
 
         logger.info('rel_recs count: {0}'.format(rel_recs.count()))
         if cat_uid_arr:
-            rand_recs = MPost.query_cat_random(cat_uid_arr[0],
-                                               limit=4 - rel_recs.count() + 4)
+            rand_recs = MPost.query_cat_random(
+                cat_uid_arr[0], limit=4 - rel_recs.count() + 4
+            )
         else:
-            rand_recs = MPost.query_random(num=4 - rel_recs.count() + 4,
-                                           kind=self.kind)
+            rand_recs = MPost.query_random(num=4 - rel_recs.count() + 4, kind=self.kind)
         return rand_recs, rel_recs
 
     def _add_relation(self, f_uid, t_uid):
@@ -528,7 +541,11 @@ class PostHandler(BaseHandler):
         post_data = {}
         ext_dic = {}
         for key in self.request.arguments:
-            if key.startswith('ext_') or key.startswith('tag_') or key.startswith('_tag_'):
+            if (
+                    key.startswith('ext_')
+                    or key.startswith('tag_')
+                    or key.startswith('_tag_')
+            ):
                 ext_dic[key] = self.get_argument(key, default='')
             else:
                 post_data[key] = self.get_arguments(key)[0]
@@ -540,16 +557,14 @@ class PostHandler(BaseHandler):
 
         if 'tags' in post_data:
             ext_dic['def_tag_arr'] = [
-                x.strip()
-                for x in post_data['tags'].strip().strip(',').split(',')
+                x.strip() for x in post_data['tags'].strip().strip(',').split(',')
             ]
         ext_dic = dict(ext_dic, **self.ext_post_data(postdata=post_data))
 
         return (post_data, ext_dic)
 
     @tornado.web.authenticated
-    @privilege.auth_add
-    # @tornado.web.asynchronous
+    @privilege.permission(action='can_add')
     @tornado.gen.coroutine
     def add(self, **kwargs):
         '''
@@ -565,10 +580,7 @@ class PostHandler(BaseHandler):
         title = post_data['title'].strip()
 
         if len(title) < 2:
-            kwd = {
-                'info': 'Title cannot be less than 2 characters',
-                'link': '/'
-            }
+            kwd = {'info': 'Title cannot be less than 2 characters', 'link': '/'}
             self.render('misc/html/404.html', userinfo=self.userinfo, kwd=kwd)
 
         if 'valid' in post_data:
@@ -597,11 +609,11 @@ class PostHandler(BaseHandler):
 
         # cele_gen_whoosh.delay()
         tornado.ioloop.IOLoop.instance().add_callback(self.cele_gen_whoosh)
-        self.redirect('/{0}/{1}'.format(router_post[self.kind], uid))
+        self.redirect('/{0}/{1}'.format(post_cfg[self.kind]['router'], uid))
 
     # @tornado.web.asynchronous
     @tornado.web.authenticated
-    @privilege.auth_edit
+    @privilege.permission(action='can_edit')
     @tornado.gen.coroutine
     def update(self, uid):
         '''
@@ -661,7 +673,12 @@ class PostHandler(BaseHandler):
         if postinfo.state[1] == '2':
             approved_state_arr = ['1', '2', '3', '4', '5', '6', '7', '8', '9']
             if len(approved_state_arr) > approved_count:
-                pstate = postinfo.state[0] + '1' + str(approved_state_arr[approved_count]) + '0'
+                pstate = (
+                        postinfo.state[0]
+                        + '1'
+                        + str(approved_state_arr[approved_count])
+                        + '0'
+                )
             else:
                 pstate = postinfo.state[0] + '190'
             MPost.update_state(uid, pstate)
@@ -676,10 +693,10 @@ class PostHandler(BaseHandler):
         logger.info('post kind:' + self.kind)
         # cele_gen_whoosh.delay()
         tornado.ioloop.IOLoop.instance().add_callback(self.cele_gen_whoosh)
-        self.redirect('/{0}/{1}'.format(router_post[postinfo.kind], uid))
+        self.redirect('/{0}/{1}'.format(post_cfg[postinfo.kind]['router'], uid))
 
     @tornado.web.authenticated
-    @privilege.auth_delete
+    @privilege.permission(action='can_delete')
     def _delete(self, *args, **kwargs):
         '''
         delete the post.
@@ -694,7 +711,7 @@ class PostHandler(BaseHandler):
 
             MCategory.update_count(current_infor.extinfo['def_cat_uid'])
 
-            if router_post[self.kind] == 'info':
+            if post_cfg[self.kind]['router'] == 'info':
                 url = "filter"
                 id_dk8 = current_infor.extinfo['def_cat_uid']
 
@@ -705,7 +722,7 @@ class PostHandler(BaseHandler):
             self.redirect('/{0}/{1}'.format(url, id_dk8))
 
         else:
-            self.redirect('/{0}/{1}'.format(router_post[self.kind], uid))
+            self.redirect('/{0}/{1}'.format(post_cfg[self.kind]['router'], uid))
 
     def _chuli_cookie_relation(self, app_id):
         '''
@@ -740,9 +757,11 @@ class PostHandler(BaseHandler):
         return {}
 
     def _add_download_entity(self, ext_dic):
-        download_url = (ext_dic['tag_file_download'].strip().lower()
-                        if ('tag_file_download' in ext_dic)
-                        else '')
+        download_url = (
+            ext_dic['tag_file_download'].strip().lower()
+            if ('tag_file_download' in ext_dic)
+            else ''
+        )
         the_entity = MEntity.get_id_by_impath(download_url)
         if the_entity:
             return True
@@ -758,18 +777,23 @@ class PostHandler(BaseHandler):
             pass
         else:
             self.redirect('/')
-        postinfo = MPost.get_by_uid(post_uid, )
+        postinfo = MPost.get_by_uid(
+            post_uid,
+        )
         json_cnt = json.dumps(postinfo.extinfo, indent=True)
         kwd = {}
-        self.render('man_info/post_kind.html',
-                    postinfo=postinfo,
-                    sig_dic=router_post,
-                    userinfo=self.userinfo,
-                    json_cnt=json_cnt,
-                    kwd=kwd)
+        self.render(
+            'man_info/post_kind.html',
+            postinfo=postinfo,
+            sig_dic=post_cfg,
+            userinfo=self.userinfo,
+            json_cnt=json_cnt,
+            kwd=kwd,
+        )
 
+    # @privilege.permission(action='can_edit')
     @tornado.web.authenticated
-    @privilege.auth_edit
+    @privilege.app_can_edit
     def _change_kind(self, post_uid):
         '''
         To modify the category of the post, and kind.
@@ -783,5 +807,4 @@ class PostHandler(BaseHandler):
         # self.update_category(post_uid)
 
         update_category(post_uid, post_data)
-        self.redirect('/{0}/{1}'.format(router_post[post_data['kcat']],
-                                        post_uid))
+        self.redirect('/{0}/{1}'.format(post_cfg[post_data['kcat']['router']], post_uid))
