@@ -1,17 +1,16 @@
 # -*- coding:utf-8 -*-
-
 '''
 Relationship between Posts.
 '''
 
 from torcms.core.base_handler import BaseHandler
-from torcms.model.relation_model import MRelation
 from torcms.model.post_model import MPost
+from torcms.model.relation_model import MRelation
 
 
 class RelHandler(BaseHandler):
     def initialize(self):
-        super(RelHandler, self).initialize()
+        super().initialize()
 
     def get(self, *args, **kwargs):
 
