@@ -10,21 +10,21 @@ import requests
 
 # from torcms.model.wiki_model import MWiki
 import config
-from config import router_post
+from config import post_cfg
 from torcms.core.tools import timestamp
 from torcms.model.category_model import MCategory
 from torcms.model.post2catalog_model import MPost2Catalog
 from torcms.model.post_model import MPost
 
 HTML_TMPL = '''<!doctype html><html><head><title></title>
-<script src="https://www.osgeo.cn/_f2elib/jquery/jquery-3.3.1.min.js"></script>
-<script src="https://www.osgeo.cn/_f2elib/bootstrap_3.3.7/js/bootstrap.min.js"></script>
+<script src="https://www.osgeo.cn/_f2elib/jquery/jquery-3.6.min.js"></script>
+<script src="https://www.osgeo.cn/_f2elib/bootstrap-3.4/js/bootstrap.min.js"></script>
 <script src="https://www.osgeo.cn/_f2elib/jquery-validate_1.15.0/jquery.validate.min.js"></script>
 <script src="https://www.osgeo.cn/_f2elib/magnific-popup_1.1.0/jquery.magnific-popup.min.js"></script>
-<script src="https://www.osgeo.cn/_f2elib/leaflet_1.7.1/leaflet.js"></script>
+<script src="https://www.osgeo.cn/_f2elib/leaflet-1.9/leaflet.js"></script>
 <script src="https://www.osgeo.cn/_f2elib/leaflet/leaflet.ChineseTmsProviders.js"></script>
 <link rel="stylesheet" href="https://www.osgeo.cn/_f2elib/bootstrap_3.3.7/css/bootstrap.min.css">
-<link rel="stylesheet" href="https://www.osgeo.cn/_f2elib/leaflet_1.7.1/leaflet.css">
+<link rel="stylesheet" href="https://www.osgeo.cn/_f2elib/leaflet-1.9/leaflet.css">
 </head>
 <body>
 <div class="container">
@@ -69,23 +69,26 @@ def check200():
 
     tstr = ''
     idx = 1
-    for kind in config.router_post.keys():
+    for kind in config.post_cfg.keys():
         posts = MPost.query_all(kind=kind, limit=20000)
         for post in posts:
             the_url0 = '{site_url}/{kind_url}/{uid}'.format(
                 site_url=config.SITE_CFG['site_url'],
-                kind_url=config.router_post[post.kind],
-                uid=post.uid)
+                kind_url=config.post_cfg[post.kind]['router'],
+                uid=post.uid,
+            )
 
             the_url = '{site_url}/{kind_url}/_edit/{uid}'.format(
                 site_url=config.SITE_CFG['site_url'],
-                kind_url=config.router_post[post.kind],
-                uid=post.uid)
+                kind_url=config.post_cfg[post.kind]['router'],
+                uid=post.uid,
+            )
 
             the_url2 = '{site_url}/{kind_url}/_edit_kind/{uid}'.format(
                 site_url=config.SITE_CFG['site_url'],
-                kind_url=config.router_post[post.kind],
-                uid=post.uid)
+                kind_url=config.post_cfg[post.kind]['router'],
+                uid=post.uid,
+            )
 
             req = requests.get(the_url0)
 
@@ -104,8 +107,8 @@ def check200():
 
     time_local = time.localtime(timestamp())
     with open(
-            'xx_err_200_{d}.html'.format(
-                d=str(time.strftime("%Y_%m_%d", time_local))), 'w') as fileo:
+        'xx_err_200_{d}.html'.format(d=str(time.strftime("%Y_%m_%d", time_local))), 'w'
+    ) as fileo:
         fileo.write(HTML_TMPL.format(cnt=tstr))
     print('Checking 200 finished.')
 
@@ -114,7 +117,7 @@ def check_kind():
     '''
     对 post 与 对应类型的 kind 进行检查
     '''
-    for kindv in router_post:
+    for kindv in post_cfg.keys():
         for rec_cat in MCategory.query_all(kind=kindv):
             catid = rec_cat.uid
             catinfo = MCategory.get_by_uid(catid)
@@ -133,7 +136,7 @@ def check_tag():
     print('Checking tag error: ')
     tstr = ''
     idx = 1
-    for kind in config.router_post.keys():
+    for kind in config.post_cfg.keys():
         posts = MPost.query_all(kind=kind, limit=20000)
 
         for post in posts:
@@ -146,24 +149,30 @@ def check_tag():
                 if catinfo:
                     p_catinfo = MCategory.get_by_uid(catinfo.pid)
 
-            if post.extinfo.get('def_cat_pid') and post.extinfo.get(
-                    'gcat0') and p_catinfo:
+            if (
+                post.extinfo.get('def_cat_pid')
+                and post.extinfo.get('gcat0')
+                and p_catinfo
+            ):
 
                 pass
             else:
                 the_url0 = '{site_url}/{kind_url}/{uid}'.format(
                     site_url=config.SITE_CFG['site_url'],
-                    kind_url=config.router_post[post.kind],
-                    uid=post.uid)
+                    kind_url=config.post_cfg[post.kind]['router'],
+                    uid=post.uid,
+                )
 
                 the_url = '{site_url}/{kind_url}/_edit/{uid}'.format(
                     site_url=config.SITE_CFG['site_url'],
-                    kind_url=config.router_post[post.kind],
-                    uid=post.uid)
+                    kind_url=config.post_cfg[post.kind]['router'],
+                    uid=post.uid,
+                )
                 the_url2 = '{site_url}/{kind_url}/_edit_kind/{uid}'.format(
                     site_url=config.SITE_CFG['site_url'],
-                    kind_url=config.router_post[post.kind],
-                    uid=post.uid)
+                    kind_url=config.post_cfg[post.kind]['router'],
+                    uid=post.uid,
+                )
                 req = requests.get(the_url0)
 
                 if req.status_code == 200:
@@ -181,8 +190,8 @@ def check_tag():
 
     time_local = time.localtime(timestamp())
     with open(
-            'xx_err_tag_{d}.html'.format(
-                d=str(time.strftime("%Y_%m_%d", time_local))), 'w') as fileo:
+        'xx_err_tag_{d}.html'.format(d=str(time.strftime("%Y_%m_%d", time_local))), 'w'
+    ) as fileo:
         fileo.write(HTML_TMPL.format(cnt=tstr))
     print('Checking 200 finished.')
 
