@@ -3,12 +3,33 @@
 删除所有的表。
 '''
 
-from torcms.model.core_tab import (TabCollect, TabEntity, TabEntity2User,
-                                   TabEvaluation, TabLink, TabLog, TabMember,
-                                   TabPost, TabPost2Tag, TabPostHist,
-                                   TabRating, TabReferrer, TabRel, TabReply,
-                                   TabReplyid, TabTag, TabUsage, TabUser2Reply,
-                                   TabWiki, TabWikiHist, TabCorrelation)
+from torcms.model.core_tab import (
+    TabCollect,
+    TabEntity,
+    TabEntity2User,
+    TabEvaluation,
+    TabLink,
+    TabLog,
+    TabMember,
+    TabPost,
+    TabPost2Tag,
+    TabPostHist,
+    TabRating,
+    TabReferrer,
+    TabRel,
+    TabReply,
+    TabReplyid,
+    TabTag,
+    TabUsage,
+    TabUser2Reply,
+    TabWiki,
+    TabWikiHist,
+    TabCorrelation,
+    TabRole,
+    TabPermission,
+    TabRole2Permission,
+    TabStaff2Role,
+)
 
 
 def drop_the_table(table_name):
@@ -29,7 +50,7 @@ def run_drop_tables(_):
 
     drop_the_table(TabPost)
     drop_the_table(TabTag)
-    drop_the_table(TabMember)
+
     drop_the_table(TabWiki)
     drop_the_table(TabLink)
     drop_the_table(TabEntity)
@@ -48,3 +69,8 @@ def run_drop_tables(_):
     drop_the_table(TabEntity2User)
     drop_the_table(TabReplyid)
     drop_the_table(TabCorrelation)
+    drop_the_table(TabStaff2Role)
+    drop_the_table(TabRole2Permission)
+    drop_the_table(TabPermission)
+    drop_the_table(TabRole)
+    drop_the_table(TabMember)
