@@ -9,8 +9,10 @@ and locale.
 '''
 import os
 
-from config import DB_CON, kind_arr, post_type
-from torcms.core.tool import run_whoosh as running_whoosh
+import torcms.core.tool.whoosh_tool
+from config import post_cfg
+
+# from torcms.core.tool import run_whoosh as running_whoosh
 from torcms.model.user_model import MUser
 
 
@@ -50,4 +52,8 @@ def run_whoosh(*args):
     '''
     running whoosh
     '''
-    running_whoosh.gen_whoosh_database(kind_arr=kind_arr, post_type=post_type)
+    kind_arr = []
+    for key, value in post_cfg.items():
+        kind_arr.append(key)
+
+    torcms.core.tool.whoosh_tool.gen_whoosh_database(kind_arr=kind_arr)
