@@ -12,6 +12,11 @@ from .script_funcs import run_create_admin, run_whoosh
 from .script_gen_category import run_gen_category
 from .script_init_tabels import run_init_tables
 from .script_zero import run_zero
+from .script_gen_role_permission import run_gen_role_permission
+from pathlib import Path
+
+XLSX_FILE = './database/role_perm.xlsx'
+
 
 
 def run_init(*args):
@@ -30,6 +35,10 @@ def run_init(*args):
         sys.exit()
 
     run_init_tables()
+
+    if Path(XLSX_FILE).exists():
+        run_gen_role_permission()
+
     run_gen_category()
     run_create_admin()
     run_whoosh()
