@@ -5,7 +5,7 @@ Check the difference of modification.
 import datetime
 import os
 
-from config import SITE_CFG, SMTP_CFG, post_emails, router_post
+from config import SITE_CFG, SMTP_CFG, post_emails, post_cfg
 from torcms.core import tools
 from torcms.core.tool.send_email import send_mail
 from torcms.core.tools import diff_table
@@ -26,10 +26,10 @@ def __get_diff_recent():
     '''
     diff_str = ''
 
-    for key in router_post:
-        recent_posts = MPost.query_recent_edited(tools.timestamp() -
-                                                 TIME_LIMIT,
-                                                 kind=key)
+    for key in post_cfg.keys():
+        recent_posts = MPost.query_recent_edited(
+            tools.timestamp() - TIME_LIMIT, kind=key
+        )
         for recent_post in recent_posts:
             hist_rec = MPostHist.get_last(recent_post.uid)
             if hist_rec:
@@ -38,14 +38,24 @@ def __get_diff_recent():
 
                 infobox = diff_table(raw_title, new_title)
 
-                diff_str = diff_str + '''
+                diff_str = (
+                    diff_str
+                    + '''
                 <h2 style="color:red;font-size:larger;font-weight:70;">TITLE: {0}</h2>
-                '''.format(recent_post.title) + infobox
+                '''.format(
+                        recent_post.title
+                    )
+                    + infobox
+                )
 
                 infobox = diff_table(hist_rec.cnt_md, recent_post.cnt_md)
 
-                diff_str = diff_str + '<h3>CONTENT:{0}</h3>'.format(
-                    recent_post.title) + infobox + '</hr>'
+                diff_str = (
+                    diff_str
+                    + '<h3>CONTENT:{0}</h3>'.format(recent_post.title)
+                    + infobox
+                    + '</hr>'
+                )
             else:
                 continue
     return diff_str
@@ -55,8 +65,7 @@ def __get_wiki_review(email_cnt, idx):
     '''
     Review for wikis.
     '''
-    recent_posts = MWiki.query_recent_edited(tools.timestamp() - TIME_LIMIT,
-                                             kind='2')
+    recent_posts = MWiki.query_recent_edited(tools.timestamp() - TIME_LIMIT, kind='2')
     for recent_post in recent_posts:
         hist_rec = MWikiHist.get_last(recent_post.uid)
         if hist_rec:
@@ -64,16 +73,22 @@ def __get_wiki_review(email_cnt, idx):
                     <tr><td>{0}</td><td>{1}</td><td class="diff_chg">Edit</td><td>{2}</td>
                     <td><a href="{3}">{3}</a></td></tr>
                     '''.format(
-                idx, recent_post.user_name, recent_post.title,
-                os.path.join(SITE_CFG['site_url'], 'page', recent_post.uid))
+                idx,
+                recent_post.user_name,
+                recent_post.title,
+                os.path.join(SITE_CFG['site_url'], 'page', recent_post.uid),
+            )
             email_cnt = email_cnt + foo_str
         else:
             foo_str = '''
                     <tr><td>{0}</td><td>{1}</td><td class="diff_add">New </td><td>{2}</td>
                     <td><a href="{3}">{3}</a></td></tr>
                     '''.format(
-                idx, recent_post.user_name, recent_post.title,
-                os.path.join(SITE_CFG['site_url'], 'page', recent_post.uid))
+                idx,
+                recent_post.user_name,
+                recent_post.title,
+                os.path.join(SITE_CFG['site_url'], 'page', recent_post.uid),
+            )
             email_cnt = email_cnt + foo_str
         idx = idx + 1
     email_cnt = email_cnt + '</table>'
@@ -92,16 +107,22 @@ def __get_page_review(email_cnt, idx):
                     <tr><td>{0}</td><td>{1}</td><td class="diff_chg">Edit</td><td>{2}</td>
                     <td><a href="{3}">{3}</a></td></tr>
                     '''.format(
-                idx, recent_post.user_name, recent_post.title,
-                os.path.join(SITE_CFG['site_url'], 'wiki', recent_post.title))
+                idx,
+                recent_post.user_name,
+                recent_post.title,
+                os.path.join(SITE_CFG['site_url'], 'wiki', recent_post.title),
+            )
             email_cnt = email_cnt + foo_str
         else:
             foo_str = '''
                     <tr><td>{0}</td><td>{1}</td><td class="diff_add">New </td><td>{2}</td>
                     <td><a href="{3}">{3}</a></td></tr>
                     '''.format(
-                idx, recent_post.user_name, recent_post.title,
-                os.path.join(SITE_CFG['site_url'], 'wiki', recent_post.title))
+                idx,
+                recent_post.user_name,
+                recent_post.title,
+                os.path.join(SITE_CFG['site_url'], 'wiki', recent_post.title),
+            )
             email_cnt = email_cnt + foo_str
         idx = idx + 1
 
@@ -112,27 +133,34 @@ def __get_post_review(email_cnt, idx):
     '''
     Review for posts.
     '''
-    for key in router_post:
-        recent_posts = MPost.query_recent_edited(tools.timestamp() -
-                                                 TIME_LIMIT,
-                                                 kind=key)
+    for key in post_cfg.keys():
+        recent_posts = MPost.query_recent_edited(
+            tools.timestamp() - TIME_LIMIT, kind=key
+        )
         for recent_post in recent_posts:
             hist_rec = MPostHist.get_last(recent_post.uid)
-            editor_name = recent_post.extinfo.get('def_editor_name',
-                                                  recent_post.user_name)
+            editor_name = recent_post.extinfo.get(
+                'def_editor_name', recent_post.user_name
+            )
             if hist_rec:
-                foo_str = ('<tr><td>{0}</td><td>{1}</td>'
-                           '<td class="diff_chg">Edit</td>'
-                           '<td>{2}</td><td><a href="{3}">{3}</a></td></tr>')
+                foo_str = (
+                    '<tr><td>{0}</td><td>{1}</td>'
+                    '<td class="diff_chg">Edit</td>'
+                    '<td>{2}</td><td><a href="{3}">{3}</a></td></tr>'
+                )
             else:
-                foo_str = ('<tr><td>{0}</td><td>{1}</td>'
-                           '<td class="diff_add">New </td>'
-                           '<td>{2}</td><td><a href="{3}">{3}</a></td></tr>')
+                foo_str = (
+                    '<tr><td>{0}</td><td>{1}</td>'
+                    '<td class="diff_add">New </td>'
+                    '<td>{2}</td><td><a href="{3}">{3}</a></td></tr>'
+                )
 
             foo_str = foo_str.format(
-                idx, editor_name, recent_post.title,
-                os.path.join(SITE_CFG['site_url'], router_post[key],
-                             recent_post.uid))
+                idx,
+                editor_name,
+                recent_post.title,
+                os.path.join(SITE_CFG['site_url'], post_cfg[key]['router'], recent_post.uid),
+            )
             email_cnt = email_cnt + foo_str
             idx = idx + 1
 
@@ -149,13 +177,15 @@ def __get_comment_list():
     comment_cnt = '<br><br><table border=1><tr><td colspan=5><center><h3>有评论的信息列表<h3></center></td></tr>'
     recent_posts = MComment.query_recent_edited(tools.timestamp() - TIME_LIMIT)
     for recent_post in recent_posts:
-        foo_str = ('<tr><td>{0}</td> '
-                   '<td>{1}</td><td><a href="{2}">{2}</a></td></tr>')
+        foo_str = '<tr><td>{0}</td> ' '<td>{1}</td><td><a href="{2}">{2}</a></td></tr>'
 
         foo_str = foo_str.format(
-            idx, recent_post.title,
-            os.path.join(SITE_CFG['site_url'], router_post[recent_post.kind],
-                         recent_post.uid))
+            idx,
+            recent_post.title,
+            os.path.join(
+                SITE_CFG['site_url'], post_cfg[recent_post.kind]['router'], recent_post.uid
+            ),
+        )
         comment_cnt = comment_cnt + foo_str
         idx = idx + 1
     comment_cnt = comment_cnt + '''</table>'''
@@ -181,7 +211,10 @@ td.diff_header {text-align:right}
 
     idx = 1
 
-    email_cnt = email_cnt + '<table border=1><tr><td colspan=5><center><h3>文档更新情况<h3></center></td></tr>'
+    email_cnt = (
+        email_cnt
+        + '<table border=1><tr><td colspan=5><center><h3>文档更新情况<h3></center></td></tr>'
+    )
 
     email_cnt, idx = __get_post_review(email_cnt, idx)  # post
     email_cnt, idx = __get_page_review(email_cnt, idx)  # page.
@@ -198,5 +231,8 @@ td.diff_header {text-align:right}
     email_cnt = email_cnt + '''</body></html>'''
 
     if idx > 1:
-        send_mail(post_emails, "{0}|{1}|{2}".format(SMTP_CFG['name'], '文档更新情况',
-                                                    DATE_STR), email_cnt)
+        send_mail(
+            post_emails,
+            "{0}|{1}|{2}".format(SMTP_CFG['name'], '文档更新情况', DATE_STR),
+            email_cnt,
+        )
