@@ -4,7 +4,7 @@ Generating sitemap.
 '''
 import os
 
-from config import SITE_CFG, router_post
+from config import SITE_CFG, post_cfg
 from torcms.model.post_model import MPost
 from torcms.model.wiki_model import MWiki
 
@@ -15,12 +15,15 @@ def gen_post_map(file_name, ext_url=''):
     :return: None
     '''
     with open(file_name, 'a') as fout:
-        for kind_key in router_post:
+        for kind_key in post_cfg.keys():
             recent_posts = MPost.query_all(kind=kind_key, limit=1000000)
             for recent_post in recent_posts:
-                url = os.path.join(SITE_CFG['site_url'],
-                                   router_post[recent_post.kind], ext_url,
-                                   recent_post.uid)
+                url = os.path.join(
+                    SITE_CFG['site_url'],
+                    post_cfg[recent_post.kind]['router'],
+                    ext_url,
+                    recent_post.uid,
+                )
                 fout.write('{url}\n'.format(url=url))
 
 
@@ -35,9 +38,9 @@ def gen_wiki_map(file_name, ext_url=''):
 
     with open(file_name, 'a') as fileout:
         for rec in wiki_recs:
-            url = os.path.join(SITE_CFG['site_url'],
-                               'wiki' + ('/_edit' if ext_url else ''),
-                               rec.title)
+            url = os.path.join(
+                SITE_CFG['site_url'], 'wiki' + ('/_edit' if ext_url else ''), rec.title
+            )
             fileout.write('{url}\n'.format(url=url))
 
     # for page.
@@ -45,8 +48,9 @@ def gen_wiki_map(file_name, ext_url=''):
 
     with open(file_name, 'a') as fileout:
         for rec in page_recs:
-            url = os.path.join(SITE_CFG['site_url'],
-                               'page' + ('/_edit' if ext_url else ''), rec.uid)
+            url = os.path.join(
+                SITE_CFG['site_url'], 'page' + ('/_edit' if ext_url else ''), rec.uid
+            )
 
             fileout.write('{url}\n'.format(url=url))
 
